Advanced Data Logger
===================

The simple data logger you are already familiar with,  records any
specified input voltage with respect to time, however, it is often
desirable to vary one output parameter, and study the effect on some
other aspect of the experiment.

In the advanced data logger, both X and Y can be chosen from the following list

- Inputs
  
   - Time
   - Voltmeter: A1,A2,A3,IN1,SEN,AN8,CCS
   - Capacitance
   - Resistance
   - Oscilloscope
     
      - Extracted frequency,phase,amplitude or offset using a sine fit
      - Difference in phase between A1(Any analog input) and A2. Also, ratio of amplitudes.
   - Frequency on IN2
   - Any connected I2C sensor (Magnetometer, accelerometer, temperature, gyro etc)
     
       - Select 1 parameter from any of the detected sensors added automatically to the list
   - SR04 distance sensor
- Outputs (Start and End must be specified)
  
    - WG Sine wave generator frequency
    - SQ1, SQ2 square wave generator
    - PV1, PV2 voltage outputs

`Online Examples
<https://csparkresearch.in/lightblog/2020-02-03-advanced-logger.html>`_
